% yamaldriver_seascorr  --- run seascorr in "input argument" mode on test data
%
% This script sets up input arguments and calls function seascorr to run on 
% the Yamal sample data used in the Computers & Geosciences manuscript.
% You may compare the results to outputs available in the online
% supplementary materials of that journal as a check.  (Be aware that
% significance thresholds can differ from run to run in Monte Carlo
% methods.)

clear all;
close all;
clc;

kcolor = 1; % '{Color'};

%---- READ TREE-RING DATA

file_tree='yamalrcs.dat'; % Tree-ring data in 2-col format
D=dlmread(file_tree);
yrx=D(:,1);
x=D(:,2);

%---- READ CLIMATE DATA
% file_P='icru3_pre_eh_70E_70N_n.dat'; % primary climate variable, 13-column ascii
% file_T='icrutem3_hadsst2_70E_70N_n.dat'; % secondary climate variable, 13-column ascii
file_P='fileP_yamal.txt'; % primary climate variable, 13-column ascii
file_T='fileT_yamal.txt'; %; % secondary climate variable, 13-column ascii

 % Note:  Missing monthly data in the original P and T files for Yamal have
 % been filled in by regularized expectation method



% Primary climate variable
D = dlmread(file_P); % 13-col numeric matrix, year as col 1
 if size(D,2)==14; % depending on line-end character, dlmread can append a column of zeros
    D(:,end)=[];
else
end
% if strcmp(version,'7.5.0.338 (R2007b)')
%  D(:,end)=[];
% end
% D = regem(D);

D = c132tss(D); % D.tsm is a 3-col matrix (year, month, data)
P=D.tsm;        % rename

% Seconndary climate variable
D = dlmread(file_T); % 13-col numeric matrix, year as col 1
%D = regem(D);


% if strcmp(version,'7.5.0.338 (R2007b)')
%  D(:,end)=[];
%end
 if size(D,2)==14; % depending on line-end character, dlmread can append a column of zeros
    D(:,end)=[];
else
 end

 
D = c132tss(D); % D.tsm is a 3-col matrix (year, month, data)
T=D.tsm; % rename


%--- SPECIFY SEASONAL GROUPING AND NUMBER OF SIMULATIONS
endmo = 11;  % September as the month marking end of growth year
g ={1,3,6,12};  % 1-month, 3-month, 9-monthe and 12-month "seasons"
nsim=1000;

%--- SET OPTIONS
kopt=[kcolor 2]; % kopt(2) == 2 specifies T will be primary climate variable and P secondary
% kopt(1) == 1 specifies color rather than B/W plots
% kopt(2) == specifies primary climate variable and secondary


%--- SET TEXT INFORMATION ON CLIMATE SERIES
textinfo{1} ='Precipitation'; % name of first climate series
textinfo{2}='P'; % one-letter code...
textinfo{3}='mm'; % units
textinfo{4}='sum'; % seasonalize by summing over months

textinfo{5} ='Temperature'; % name of first climate series
textinfo{6}='T'; % one-letter code...
textinfo{7}='deg C'; % units
textinfo{8}='mean'; % seasonalize by averaging over months

time_specs={[1903 1996],[1903 1949],[1950 1996]}; % full-period, sub-periods,


%---- Some minimal checking to avoid invalid specification of time periods
% (seascorr will also apply a check to the periods)
t1=time_specs{1};
t2=time_specs{2};
t3=time_specs{3};
if ~isempty(t1) && ~isempty(t2);
    if ~(t2(1)>=t1(1) && t3(1)>=t1(1))
        error('Do not specify a sub-period to start before the specified start year of full period');
    end
    if ~(t2(end)<=t1(end) && t3(end)<=t1(end))
        error('Do not specify a sub-period to end after the specified end year of full period');
    end
    if t2(2)>=t3(1);
        error('Do not let the two sub-periods overlap');
    end
end



%--- CALL SEASCORR
t = cputime; % allows checking cpu time required to run function (type "tcpu" at Matlab prompt after running this script
tic
R = seascorr(x,yrx,P,T,endmo,g,kopt,textinfo,nsim,time_specs);
% R=seascorr(x,yrx,P,T,endmo,g,kopt,textinfo,nsim,time_specs)
toc
tcpu=cputime-t;                           